---------
Utilities
---------

Command Line
~~~~~~~~~~~~

.. currentmodule:: africanus.util.cmdline

.. autosummary::
    parse_python_assigns

.. autofunction:: africanus.util.cmdline.parse_python_assigns


Requirements Handling
~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: africanus.util.requirements

.. autosummary::
    requires_optional

.. autofunction:: africanus.util.requirements.requires_optional

Shapes
~~~~~~

.. currentmodule:: africanus.util.shapes

.. autosummary::
    aggregate_chunks
    corr_shape

.. autofunction:: africanus.util.shapes.aggregate_chunks
.. autofunction:: africanus.util.shapes.corr_shape


Beams
~~~~~

.. currentmodule:: africanus.util.beams

.. autosummary::
    beam_filenames
    beam_grids


.. autofunction:: africanus.util.beams.beam_filenames
.. autofunction:: africanus.util.beams.beam_grids

Code
~~~~

.. currentmodule:: africanus.util.code

.. autosummary::
    format_code
    memoize_on_key

.. autofunction:: africanus.util.code.format_code
.. autoclass:: africanus.util.code.memoize_on_key


CUDA
~~~~

.. currentmodule:: africanus.util.cuda

.. autosummary::
    grids

.. autofunction:: africanus.util.cuda.grids
